@@ -198,7 +198,7 @@ ect_draw (ECellView *ecell_view, GdkDrawable *drawable,
 	ETreeModel *tree_model = e_cell_tree_get_tree_model(ecell_view->e_table_model, row);
 	ETreeTableAdapter *tree_table_adapter = e_cell_tree_get_tree_table_adapter(ecell_view->e_table_model, row);
 	ETreePath node;
-	GdkRectangle rect, *clip_rect;
+	GdkRectangle rect, *clip_rect = NULL;
 	GtkWidget *canvas = GTK_WIDGET (tree_view->canvas);
 	GdkGC *fg_gc = canvas->style->fg_gc[GTK_STATE_ACTIVE];
 	GdkColor *foreground;
@@ -264,7 +264,7 @@ ect_draw (ECellView *ecell_view, GdkDrawable *drawable,
 					       rect.x + offset - INDENT_AMOUNT / 2,
 					       rect.y,
 					       rect.x + offset - INDENT_AMOUNT / 2,
-					       (e_tree_model_node_get_next (tree_model, node)
+					       (e_tree_table_adapter_node_get_next (tree_table_adapter, node)
 						? rect.y + rect.height
 						: rect.y + rect.height / 2));
 			}
@@ -276,7 +276,7 @@ ect_draw (ECellView *ecell_view, GdkDrawable *drawable,
 			offset -= INDENT_AMOUNT;
 			depth = visible_depth_of_node (ecell_view->e_table_model, row) - 1;
 			while (parent_node && depth != 0) {
-				if (e_tree_model_node_get_next(tree_model, parent_node)) {
+				if (e_tree_table_adapter_node_get_next(tree_table_adapter, parent_node)) {
 					gdk_draw_line (drawable, tree_view->gc,
 						       rect.x + offset - INDENT_AMOUNT / 2,
 						       rect.y,
@@ -333,6 +333,11 @@ ect_draw (ECellView *ecell_view, GdkDrawable *drawable,
 	e_cell_draw (tree_view->subcell_view, drawable,
 		     model_col, view_col, row, flags,
 		     x1 + subcell_offset, y1, x2, y2);
+
+	if (clip_rect) {
+		gdk_gc_set_clip_rectangle (tree_view->gc, NULL);
+		gdk_gc_set_clip_rectangle (fg_gc, NULL);
+	}
 }
 
 /*
@@ -434,7 +439,7 @@ ect_max_width (ECellView *ecell_view, int model_col, int view_col)
 	number_of_rows = e_table_model_row_count (ecell_view->e_table_model);
 
 	if (!per_row)
-	subcell_max_width = e_cell_max_width (tree_view->subcell_view, model_col, view_col);
+		subcell_max_width = e_cell_max_width (tree_view->subcell_view, model_col, view_col);
 	
 	for (row = 0; row < number_of_rows; row++) {
 		ETreeModel *tree_model = e_cell_tree_get_tree_model(ecell_view->e_table_model, row);
@@ -512,7 +517,7 @@ ect_show_tooltip (ECellView *ecell_view, int model_col, int view_col, int row,
 	tooltip->x += offset;
 	e_cell_show_tooltip (tree_view->subcell_view, model_col, view_col, row, col_width - offset, tooltip);
 }
-		
+
 /*
  * ECellView::get_bg_color method
  */
@@ -585,7 +590,7 @@ ect_print (ECellView *ecell_view, GnomePrintContext *context,
 						    height);
 				gnome_print_lineto (context,
 						    offset - INDENT_AMOUNT / 2,
-						    (e_tree_model_node_get_next (tree_model, node)
+						    (e_tree_table_adapter_node_get_next (tree_table_adapter, node)
 						     ? 0
 						     : height / 2));
 			}
@@ -597,7 +602,7 @@ ect_print (ECellView *ecell_view, GnomePrintContext *context,
 			depth = visible_depth_of_node (ecell_view->e_table_model, row) - 1;
 			offset -= INDENT_AMOUNT;
 			while (node && depth != 0) {
-				if (e_tree_model_node_get_next(tree_model, node)) {
+				if (e_tree_table_adapter_node_get_next(tree_table_adapter, node)) {
 					gnome_print_moveto (context,
 							    offset - INDENT_AMOUNT / 2,
 							    height);
@@ -655,16 +660,16 @@ ect_print_height (ECellView *ecell_view, GnomePrintContext *context,
 }
 
 /*
- * GtkObject::destroy method
+ * GObject::dispose method
  */
 static void
-ect_destroy (GtkObject *object)
+ect_dispose (GObject *object)
 {
 	ECellTree *ect = E_CELL_TREE (object);
 
 	/* destroy our subcell */
 	if (ect->subcell)
-		gtk_object_unref (GTK_OBJECT (ect->subcell));
+		g_object_unref (ect->subcell);
 	ect->subcell = NULL;
 
 	if (ect->open_pixbuf)
@@ -675,35 +680,35 @@ ect_destroy (GtkObject *object)
 		gdk_pixbuf_unref (ect->closed_pixbuf);
 	ect->closed_pixbuf = NULL;
 
-	GTK_OBJECT_CLASS (parent_class)->destroy (object);
+	G_OBJECT_CLASS (parent_class)->dispose (object);
 }
 
 static void
-e_cell_tree_class_init (GtkObjectClass *object_class)
+e_cell_tree_class_init (GObjectClass *object_class)
 {
 	ECellClass *ecc = (ECellClass *) object_class;
 
-	object_class->destroy = ect_destroy;
+	object_class->dispose = ect_dispose;
 
-	ecc->new_view   = ect_new_view;
-	ecc->kill_view  = ect_kill_view;
-	ecc->realize    = ect_realize;
-	ecc->unrealize  = ect_unrealize;
-	ecc->draw       = ect_draw;
-	ecc->event      = ect_event;
-	ecc->height     = ect_height;
-	ecc->enter_edit = ect_enter_edit;
-	ecc->leave_edit = ect_leave_edit;
-	ecc->print      = ect_print;
-	ecc->print_height = ect_print_height;
-	ecc->max_width = ect_max_width;
-	ecc->show_tooltip = ect_show_tooltip;
+	ecc->new_view         = ect_new_view;
+	ecc->kill_view        = ect_kill_view;
+	ecc->realize          = ect_realize;
+	ecc->unrealize        = ect_unrealize;
+	ecc->draw             = ect_draw;
+	ecc->event            = ect_event;
+	ecc->height           = ect_height;
+	ecc->enter_edit       = ect_enter_edit;
+	ecc->leave_edit       = ect_leave_edit;
+	ecc->print            = ect_print;
+	ecc->print_height     = ect_print_height;
+	ecc->max_width        = ect_max_width;
+	ecc->show_tooltip     = ect_show_tooltip;
 	ecc->get_bg_color     = ect_get_bg_color;
 
-	parent_class = gtk_type_class (PARENT_TYPE);
+	parent_class = g_type_class_ref (PARENT_TYPE);
 }
 
-E_MAKE_TYPE(e_cell_tree, "ECellTree", ECellTree, e_cell_tree_class_init, NULL, PARENT_TYPE);
+E_MAKE_TYPE(e_cell_tree, "ECellTree", ECellTree, e_cell_tree_class_init, NULL, PARENT_TYPE)
 
 /**
  * e_cell_tree_construct:
@@ -726,7 +731,7 @@ e_cell_tree_construct (ECellTree *ect,
 {		       
 	ect->subcell = subcell;
 	if (subcell) {
-		gtk_object_ref (GTK_OBJECT (subcell));
+		g_object_ref (subcell);
 		gtk_object_sink (GTK_OBJECT (subcell));
 	}
 	if (open_pixbuf)
@@ -764,7 +769,7 @@ e_cell_tree_new (GdkPixbuf *open_pixbuf,
 		 gboolean draw_lines,
 		 ECell *subcell)
 {
-	ECellTree *ect = gtk_type_new (e_cell_tree_get_type ());
+	ECellTree *ect = g_object_new (E_CELL_TREE_TYPE, NULL);
 
 	e_cell_tree_construct (ect, open_pixbuf, closed_pixbuf, draw_lines, subcell);
 
