@@ -31,6 +31,7 @@
 #include <gal/e-table/e-table-simple.h>
 #include <gal/e-table/e-table-scrolled.h>
 #include <gal/util/e-i18n.h>
+#include "gal/util/e-marshal.h"
 
 enum {
 	E_COMPLETION_VIEW_NONEMPTY,
@@ -54,8 +55,9 @@ static gint    e_completion_view_key_press_handler (GtkWidget *w, GdkEventKey *k
 
 static void    e_completion_view_class_init (ECompletionViewClass *klass);
 static void    e_completion_view_init       (ECompletionView *completion);
-static void    e_completion_view_destroy    (GtkObject *object);
+static void    e_completion_view_dispose    (GObject *object);
 
+#define PARENT_TYPE GTK_TYPE_EVENT_BOX
 static GtkObjectClass *parent_class;
 
 
@@ -90,6 +92,7 @@ e_completion_view_paint (GtkWidget *widget, GdkRectangle *area)
 	
 }
 
+#if 0
 static void
 e_completion_view_draw (GtkWidget *widget, GdkRectangle *area)
 {
@@ -109,6 +112,7 @@ e_completion_view_draw (GtkWidget *widget, GdkRectangle *area)
 			gtk_widget_draw (bin->child, &child_area);
 	}
 }
+#endif
 
 static gint
 e_completion_view_expose_event (GtkWidget *widget, GdkEventExpose *event)			  
@@ -129,7 +133,7 @@ e_completion_view_expose_event (GtkWidget *widget, GdkEventExpose *event)
 		if (bin->child &&
 		    GTK_WIDGET_NO_WINDOW (bin->child) &&
 		    gtk_widget_intersect (bin->child, &event->area, &child_event.area))
-			gtk_widget_event (bin->child, (GdkEvent*) &child_event);
+			gtk_widget_send_expose (bin->child, (GdkEvent*) &child_event);
 	}
 
 	return FALSE;
@@ -157,6 +161,8 @@ e_completion_view_size_request (GtkWidget *widget, GtkRequisition *requisition)
 		requisition->width += child_requisition.width;
 		requisition->height += child_requisition.height;
 	}
+
+	requisition->height = MAX (100, requisition->height);
 }
 
 static void
@@ -191,92 +197,80 @@ e_completion_view_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 	}
 }
 
-GtkType
-e_completion_view_get_type (void)
-{
-	static GtkType completion_view_type = 0;
-  
-	if (!completion_view_type) {
-		GtkTypeInfo completion_view_info = {
-			"ECompletionView",
-			sizeof (ECompletionView),
-			sizeof (ECompletionViewClass),
-			(GtkClassInitFunc) e_completion_view_class_init,
-			(GtkObjectInitFunc) e_completion_view_init,
-			NULL, NULL, /* reserved */
-			(GtkClassInitFunc) NULL
-		};
-
-		completion_view_type = gtk_type_unique (gtk_event_box_get_type (), &completion_view_info);
-	}
-
-	return completion_view_type;
-}
-
+E_MAKE_TYPE (e_completion_view,
+	     "ECompletionView",
+	     ECompletionView,
+	     e_completion_view_class_init,
+	     e_completion_view_init,
+	     PARENT_TYPE)
+	     
 static void
 e_completion_view_class_init (ECompletionViewClass *klass)
 {
-	GtkObjectClass *object_class = (GtkObjectClass *) klass;
+	GObjectClass *object_class = (GObjectClass *) klass;
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-	parent_class = GTK_OBJECT_CLASS (gtk_type_class (gtk_event_box_get_type ()));
+	parent_class = g_type_class_ref (PARENT_TYPE);
 
 	e_completion_view_signals[E_COMPLETION_VIEW_NONEMPTY] =
-		gtk_signal_new ("nonempty",
-				GTK_RUN_LAST,
-				E_OBJECT_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (ECompletionViewClass, nonempty),
-				gtk_marshal_NONE__NONE,
-				GTK_TYPE_NONE, 0);
+		g_signal_new ("nonempty",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (ECompletionViewClass, nonempty),
+			      NULL, NULL,
+			      e_marshal_NONE__NONE,
+			      G_TYPE_NONE, 0);
 
 	e_completion_view_signals[E_COMPLETION_VIEW_ADDED] =
-		gtk_signal_new ("added",
-				GTK_RUN_LAST,
-				E_OBJECT_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (ECompletionViewClass, added),
-				gtk_marshal_NONE__NONE,
-				GTK_TYPE_NONE, 0);
+		g_signal_new ("added",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (ECompletionViewClass, added),
+			      NULL, NULL,
+			      e_marshal_NONE__NONE,
+			      G_TYPE_NONE, 0);
 
 	e_completion_view_signals[E_COMPLETION_VIEW_FULL] =
-		gtk_signal_new ("full",
-				GTK_RUN_LAST,
-				E_OBJECT_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (ECompletionViewClass, full),
-				gtk_marshal_NONE__NONE,
-				GTK_TYPE_NONE, 0);
+		g_signal_new ("full",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (ECompletionViewClass, full),
+			      NULL, NULL,
+			      e_marshal_NONE__NONE,
+			      G_TYPE_NONE, 0);
 
 	e_completion_view_signals[E_COMPLETION_VIEW_BROWSE] =
-		gtk_signal_new ("browse",
-				GTK_RUN_LAST,
-				E_OBJECT_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (ECompletionViewClass, browse),
-				gtk_marshal_NONE__POINTER,
-				GTK_TYPE_NONE, 1,
-				GTK_TYPE_POINTER);
+		g_signal_new ("browse",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (ECompletionViewClass, browse),
+			      NULL, NULL,
+			      e_marshal_NONE__POINTER,
+			      G_TYPE_NONE, 1,
+			      G_TYPE_POINTER);
 
 	e_completion_view_signals[E_COMPLETION_VIEW_UNBROWSE] =
-		gtk_signal_new ("unbrowse",
-				GTK_RUN_LAST,
-				E_OBJECT_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (ECompletionViewClass, unbrowse),
-				gtk_marshal_NONE__NONE,
-				GTK_TYPE_NONE, 0);
+		g_signal_new ("unbrowse",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (ECompletionViewClass, unbrowse),
+			      NULL, NULL,
+			      e_marshal_NONE__NONE,
+			      G_TYPE_NONE, 0);
 
 	e_completion_view_signals[E_COMPLETION_VIEW_ACTIVATE] =
-		gtk_signal_new ("activate",
-				GTK_RUN_LAST,
-				E_OBJECT_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (ECompletionViewClass, activate),
-				gtk_marshal_NONE__POINTER,
-				GTK_TYPE_NONE, 1,
-				GTK_TYPE_POINTER);
+		g_signal_new ("activate",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (ECompletionViewClass, activate),
+			      NULL, NULL,
+			      e_marshal_NONE__POINTER,
+			      G_TYPE_NONE, 1,
+			      G_TYPE_POINTER);
 
-	E_OBJECT_CLASS_ADD_SIGNALS (object_class, e_completion_view_signals, E_COMPLETION_VIEW_LAST_SIGNAL);
-
-	object_class->destroy = e_completion_view_destroy;
+	object_class->dispose = e_completion_view_dispose;
 
 	widget_class->key_press_event = e_completion_view_local_key_press_handler;
-	widget_class->draw = e_completion_view_draw;
 	widget_class->expose_event = e_completion_view_expose_event;
 	widget_class->size_request = e_completion_view_size_request;
 	widget_class->size_allocate = e_completion_view_size_allocate;
@@ -290,26 +284,31 @@ e_completion_view_init (ECompletionView *completion)
 }
 
 static void
-e_completion_view_destroy (GtkObject *object)
+e_completion_view_dispose (GObject *object)
 {
 	ECompletionView *cv = E_COMPLETION_VIEW (object);
 
 	e_completion_view_disconnect (cv);
-	e_completion_view_clear_choices (cv);
 
-	g_ptr_array_free (cv->choices, TRUE);
+	if (cv->choices) {
+		e_completion_view_clear_choices (cv);
+
+		g_ptr_array_free (cv->choices, TRUE);
+		cv->choices = NULL;
+	}
 
 	if (cv->key_widget) {
-		gtk_signal_disconnect (GTK_OBJECT (cv->key_widget), cv->key_signal_id);
-		gtk_object_unref (GTK_OBJECT (cv->key_widget));
+		g_signal_handler_disconnect (cv->key_widget, cv->key_signal_id);
+		g_object_unref (cv->key_widget);
+		cv->key_widget = NULL;
 	}
 
 	if (cv->completion)
-		gtk_object_unref (GTK_OBJECT (cv->completion));
+		g_object_unref (cv->completion);
+	cv->completion = NULL;
 
-
-	if (parent_class->destroy)
-		(parent_class->destroy) (object);
+	if (G_OBJECT_CLASS (parent_class)->dispose)
+		(G_OBJECT_CLASS (parent_class)->dispose) (object);
 }
 
 static void
@@ -319,26 +318,15 @@ e_completion_view_disconnect (ECompletionView *cv)
 	g_return_if_fail (E_IS_COMPLETION_VIEW (cv));
 
 	if (cv->begin_signal_id)
-		gtk_signal_disconnect (GTK_OBJECT (cv->completion), cv->begin_signal_id);
+		g_signal_handler_disconnect (cv->completion, cv->begin_signal_id);
 	if (cv->comp_signal_id)
-		gtk_signal_disconnect (GTK_OBJECT (cv->completion), cv->comp_signal_id);
-	if (cv->restart_signal_id)
-		gtk_signal_disconnect (GTK_OBJECT (cv->completion), cv->restart_signal_id);
-	if (cv->cancel_signal_id)
-		gtk_signal_disconnect (GTK_OBJECT (cv->completion), cv->cancel_signal_id);
+		g_signal_handler_disconnect (cv->completion, cv->comp_signal_id);
 	if (cv->end_signal_id)
-		gtk_signal_disconnect (GTK_OBJECT (cv->completion), cv->end_signal_id);
-	if (cv->clear_signal_id)
-		gtk_signal_disconnect (GTK_OBJECT (cv->completion), cv->clear_signal_id);
-	if (cv->lost_signal_id)
-		gtk_signal_disconnect (GTK_OBJECT (cv->completion), cv->lost_signal_id);
+		g_signal_handler_disconnect (cv->completion, cv->end_signal_id);
 
 	cv->begin_signal_id   = 0;
 	cv->comp_signal_id    = 0;
-	cv->restart_signal_id = 0;
 	cv->end_signal_id     = 0;
-	cv->clear_signal_id   = 0;
-	cv->lost_signal_id    = 0;
 }
 
 static ETable *
@@ -383,7 +371,7 @@ e_completion_view_set_cursor_row (ECompletionView *cv, gint r)
 	}
 #endif
 
-	adj = e_scroll_frame_get_vadjustment (E_SCROLL_FRAME (cv->table));	
+	adj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (cv->table));	
 
 	table = e_completion_view_table (cv);
 
@@ -443,7 +431,7 @@ e_completion_view_select (ECompletionView *cv, gint r)
 
 	cv->selection = r;
 	e_completion_view_set_cursor_row (cv, r);
-	gtk_signal_emit (GTK_OBJECT (cv), e_completion_view_signals[E_COMPLETION_VIEW_ACTIVATE], match);
+	g_signal_emit (cv, e_completion_view_signals[E_COMPLETION_VIEW_ACTIVATE], 0, match);
 }
 
 static gint
@@ -467,14 +455,14 @@ e_completion_view_key_press_handler (GtkWidget *w, GdkEventKey *key_event, gpoin
 	
 	/* Start up a completion.*/
 	if (complete_key && !cv->editable) {
-		gtk_signal_emit (GTK_OBJECT (cv), e_completion_view_signals[E_COMPLETION_VIEW_BROWSE], NULL);
+		g_signal_emit (cv, e_completion_view_signals[E_COMPLETION_VIEW_BROWSE], 0, NULL);
 		goto stop_emission;
 	}
 
 	/* Stop our completion. */
 	if (uncomplete_key && cv->editable && cv->selection < 0) {
 		e_completion_view_set_cursor_row (cv, -1);
-		gtk_signal_emit (GTK_OBJECT (cv), e_completion_view_signals[E_COMPLETION_VIEW_UNBROWSE]);
+		g_signal_emit (cv, e_completion_view_signals[E_COMPLETION_VIEW_UNBROWSE], 0);
 		goto stop_emission;
 	}
 
@@ -570,15 +558,15 @@ e_completion_view_key_press_handler (GtkWidget *w, GdkEventKey *key_event, gpoin
 	e_completion_view_set_cursor_row (cv, cv->selection);
 
 	if (cv->selection >= 0)
-		gtk_signal_emit (GTK_OBJECT (cv), e_completion_view_signals[E_COMPLETION_VIEW_BROWSE], 
-				 g_ptr_array_index (cv->choices, cv->selection));
+		g_signal_emit (cv, e_completion_view_signals[E_COMPLETION_VIEW_BROWSE], 0,
+			       g_ptr_array_index (cv->choices, cv->selection));
 	else
-		gtk_signal_emit (GTK_OBJECT (cv), e_completion_view_signals[E_COMPLETION_VIEW_UNBROWSE]);
+		g_signal_emit (cv, e_completion_view_signals[E_COMPLETION_VIEW_UNBROWSE], 0);
 
  stop_emission:
 	
 	if (key_handled)
-		gtk_signal_emit_stop_by_name (GTK_OBJECT (w), "key_press_event");
+		g_signal_stop_emission_by_name (w, "key_press_event");
 
 	return key_handled;
 }
@@ -588,33 +576,13 @@ begin_completion_cb (ECompletion *completion, const gchar *txt, gint pos, gint l
 {
 	ECompletionView *cv = E_COMPLETION_VIEW (user_data);
 
+	e_table_model_pre_change (cv->model);
 	e_completion_view_clear_choices (cv);
 	cv->have_all_choices = FALSE;
 
 	e_table_model_changed (cv->model);
 }
 
-static void
-restart_completion_cb (ECompletion *completion, gpointer user_data)
-{
-	/* For now, handle restarts like the beginning of a new completion. */
-	begin_completion_cb (completion, NULL, 0, 0, user_data);
-}
-
-static void
-cancel_completion_cb (ECompletion *completion, gpointer user_data)
-{
-	ECompletionView *cv = E_COMPLETION_VIEW (user_data);
-
-	/* On a cancel, clear our choices and issue an "unbrowse" signal. */
-	e_completion_view_clear_choices (cv);
-	cv->have_all_choices = TRUE;
-	e_completion_view_set_cursor_row (cv, -1);
-	e_table_model_changed (cv->model);
-
-	gtk_signal_emit (GTK_OBJECT (cv), e_completion_view_signals[E_COMPLETION_VIEW_UNBROWSE]);
-}
-
 static void
 completion_cb (ECompletion *completion, ECompletionMatch *match, gpointer user_data)
 {
@@ -622,15 +590,17 @@ completion_cb (ECompletion *completion, ECompletionMatch *match, gpointer user_d
 	gint r = cv->choices->len;
 	gboolean first = (cv->choices->len == 0);
 
+	e_table_model_pre_change (cv->model);
+
 	e_completion_match_ref (match);
 	g_ptr_array_add (cv->choices, match);
 
 	e_table_model_row_inserted (cv->model, r);
 
 	if (first)
-		gtk_signal_emit (GTK_OBJECT (cv), e_completion_view_signals[E_COMPLETION_VIEW_NONEMPTY]);
+		g_signal_emit (cv, e_completion_view_signals[E_COMPLETION_VIEW_NONEMPTY], 0);
 
-	gtk_signal_emit (GTK_OBJECT (cv), e_completion_view_signals[E_COMPLETION_VIEW_ADDED]);
+	g_signal_emit (cv, e_completion_view_signals[E_COMPLETION_VIEW_ADDED], 0);
 }
 
 static void
@@ -639,46 +609,17 @@ end_completion_cb (ECompletion *completion, gpointer user_data)
 	ECompletionView *cv = E_COMPLETION_VIEW (user_data);
 
 	/* Do a final refresh of the table. */
+	e_table_model_pre_change (cv->model);
 	e_table_model_changed (cv->model);
 
 	cv->have_all_choices = TRUE;
-	gtk_signal_emit (GTK_OBJECT (cv), e_completion_view_signals[E_COMPLETION_VIEW_FULL]);
-}
-
-static void
-clear_completion_cb (ECompletion *completion, gpointer user_data)
-{
-	ECompletionView *cv = E_COMPLETION_VIEW (user_data);
-
-	e_completion_view_clear_choices (cv);
-	cv->have_all_choices = FALSE;
-
-	e_table_model_changed (cv->model);
-}
-
-static void
-lost_completion_cb (ECompletion *completion, ECompletionMatch *match, gpointer user_data)
-{
-	ECompletionView *cv = E_COMPLETION_VIEW (user_data);
-	int i;
-	GPtrArray *c = cv->choices;
-
-	for (i = 0; i < c->len; i++)
-		if (g_ptr_array_index (c, i) == match)
-			break;
-
-	g_return_if_fail (i == c->len);
-
-	/* FIXME: do remove_index_fast(), then row_changed and
-	 * row_deleted (if there are more than 1 row still) */
-	g_ptr_array_remove_index (c, i);
-	e_table_model_row_deleted (cv->model, i);
-	
-	e_completion_match_unref (match);
+	g_signal_emit (cv, e_completion_view_signals[E_COMPLETION_VIEW_FULL], 0);
 }
 
 /*** Table Callbacks ***/
 
+/* XXX toshok - we need to add sorting to this etable, through the use
+   of undisplayed fields of all the sort keys we want to use */
 static char *simple_spec = 
 "<ETableSpecification no-headers=\"true\" draw-grid=\"false\" cursor-mode=\"line\" alternating-row-colors=\"false\" gettext-domain=\"" E_I18N_DOMAIN "\">"
 "  <ETableColumn model_col=\"0\" _title=\"Node\" expansion=\"1.0\" "
@@ -748,36 +689,20 @@ e_completion_view_construct (ECompletionView *cv, ECompletion *completion)
 	GTK_WIDGET_SET_FLAGS (GTK_WIDGET (cv), GTK_CAN_FOCUS);
 
 	cv->completion = completion;
-	gtk_object_ref (GTK_OBJECT (completion));
+	g_object_ref (completion);
 
-	cv->begin_signal_id   = gtk_signal_connect (GTK_OBJECT (completion),
-						    "begin_completion",
-						    GTK_SIGNAL_FUNC (begin_completion_cb),
-						    cv);
-	cv->comp_signal_id    = gtk_signal_connect (GTK_OBJECT (completion),
-						    "completion",
-						    GTK_SIGNAL_FUNC (completion_cb),
-						    cv);
-	cv->restart_signal_id = gtk_signal_connect (GTK_OBJECT (completion),
-						    "restart_completion",
-						    GTK_SIGNAL_FUNC (restart_completion_cb),
-						    cv);
-	cv->cancel_signal_id  = gtk_signal_connect (GTK_OBJECT (completion),
-						    "cancel_completion",
-						    GTK_SIGNAL_FUNC (cancel_completion_cb),
-						    cv);
-	cv->end_signal_id     = gtk_signal_connect (GTK_OBJECT (completion),
-						    "end_completion",
-						    GTK_SIGNAL_FUNC (end_completion_cb),
-						    cv);
-	cv->clear_signal_id   = gtk_signal_connect (GTK_OBJECT (completion),
-						    "clear_completion",
-						    GTK_SIGNAL_FUNC (clear_completion_cb),
-						    cv);
-	cv->lost_signal_id    = gtk_signal_connect (GTK_OBJECT (completion),
-						    "lost_completion",
-						    GTK_SIGNAL_FUNC (lost_completion_cb),
-						    cv);
+	cv->begin_signal_id   = g_signal_connect (completion,
+						  "completion_started",
+						  G_CALLBACK (begin_completion_cb),
+						  cv);
+	cv->comp_signal_id    = g_signal_connect (completion,
+						  "completion_found",
+						  G_CALLBACK (completion_cb),
+						  cv);
+	cv->end_signal_id     = g_signal_connect (completion,
+						  "completion_finished",
+						  G_CALLBACK (end_completion_cb),
+						  cv);
 
 	cv->model = e_table_simple_new (table_col_count,
 					table_row_count,
@@ -794,19 +719,18 @@ e_completion_view_construct (ECompletionView *cv, ECompletion *completion)
 					cv);
 
 	cv->table = e_table_scrolled_new (cv->model, NULL, simple_spec, NULL);
-	gtk_object_unref (GTK_OBJECT (cv->model));
+	g_object_unref (cv->model);
 
-	e_scroll_frame_set_shadow_type (E_SCROLL_FRAME (cv->table), GTK_SHADOW_NONE);
-	e_scroll_frame_set_scrollbar_spacing (E_SCROLL_FRAME (cv->table), 0);
-	e_scroll_frame_set_policy (E_SCROLL_FRAME (cv->table), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (cv->table), GTK_SHADOW_NONE);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (cv->table), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 
 	gtk_container_add (GTK_CONTAINER (cv), cv->table);
 	gtk_widget_show_all (cv->table);
 
-	gtk_signal_connect (GTK_OBJECT (e_completion_view_table (cv)),
-			    "click",
-			    GTK_SIGNAL_FUNC (table_click_cb),
-			    cv);
+	g_signal_connect (e_completion_view_table (cv),
+			  "click",
+			  G_CALLBACK (table_click_cb),
+			  cv);
 
 	cv->selection = -1;
 }
@@ -819,7 +743,7 @@ e_completion_view_new (ECompletion *completion)
 	g_return_val_if_fail (completion != NULL, NULL);
 	g_return_val_if_fail (E_IS_COMPLETION (completion), NULL);
 
-	p = gtk_type_new (e_completion_view_get_type ());
+	p = g_object_new (E_COMPLETION_VIEW_TYPE, NULL);
 
 	e_completion_view_construct (E_COMPLETION_VIEW (p), completion);
 
@@ -834,18 +758,18 @@ e_completion_view_connect_keys (ECompletionView *cv, GtkWidget *w)
 	g_return_if_fail (w == NULL || GTK_IS_WIDGET (w));
 
 	if (cv->key_widget) {
-		gtk_signal_disconnect (GTK_OBJECT (cv->key_widget), cv->key_signal_id);
-		gtk_object_unref (GTK_OBJECT (cv->key_widget));
+		g_signal_handler_disconnect (cv->key_widget, cv->key_signal_id);
+		g_object_unref (cv->key_widget);
 	}
 
 	if (w) {
 		cv->key_widget = w;
-		gtk_object_ref (GTK_OBJECT (w));
+		g_object_ref (w);
 
-		cv->key_signal_id = gtk_signal_connect (GTK_OBJECT (w),
-							"key_press_event",
-							GTK_SIGNAL_FUNC (e_completion_view_key_press_handler),
-							cv);
+		cv->key_signal_id = g_signal_connect (w,
+						      "key_press_event",
+						      G_CALLBACK (e_completion_view_key_press_handler),
+						      cv);
 	} else {
 		cv->key_widget = NULL;
 		cv->key_signal_id = 0;
