@@ -1,8 +1,11 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* EText - Text item for evolution.
- * Copyright (C) 2000 Helix Code, Inc.
+/* 
+ * e-text.h - Text item for evolution.
+ * Copyright 2000, 2001, Ximian, Inc.
  *
- * Author: Chris Lahey <clahey@umich.edu>
+ * Authors:
+ *   Chris Lahey <clahey@ximian.com>
+ *   Jon Trowbridge <trow@ximian.com>
  *
  * A majority of code taken from:
  *
@@ -14,18 +17,33 @@
  *
  * Copyright (C) 1998 The Free Software Foundation
  *
- * Author: Federico Mena <federico@nuclecu.unam.mx> */
+ * Author: Federico Mena <federico@nuclecu.unam.mx>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License, version 2, as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
+ */
 
 #ifndef E_TEXT_H
 #define E_TEXT_H
 
-#include <gnome.h>
-#include <gal/widgets/e-font.h>
-#include <gal/e-text/e-text-event-processor.h>
+#include <gtk/gtkmenu.h>
+
+#include <gal/util/e-text-event-processor.h>
 #include <gal/e-text/e-text-model.h>
+#include <gal/widgets/e-canvas.h>
 
-
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
 
 /* Text item for the canvas.  Text items are positioned by an anchor point and an anchor direction.
@@ -43,9 +61,7 @@ BEGIN_GNOME_DECLS
  * name			type			read/write	description
  * ------------------------------------------------------------------------------------------
  * text			string			RW		The string of the text label
- * font			string			W		X logical font descriptor
- * fontset		string			W		X logical fontset descriptor
- * font_gdk		GdkFont*		RW		Pointer to a GdkFont
+ * bold                 boolean                 RW              Bold?
  * anchor		GtkAnchorType		RW		Anchor side for the text
  * justification	GtkJustification	RW		Justification for multiline text
  * fill_color		string			W		X color specification for text
@@ -71,55 +87,32 @@ BEGIN_GNOME_DECLS
  * max_lines            int                     RW              Number of lines possible when doing line wrap.
  * draw_borders         boolean                 RW              Whether to draw borders.
  * draw_background      boolean                 RW              Whether to draw the background.
+ * draw_button          boolean                 RW              This makes EText handle being the child of a button properly and highlighting as it should.
  */
 
 #define E_TYPE_TEXT            (e_text_get_type ())
-#define E_TEXT(obj)            (GTK_CHECK_CAST ((obj), E_TYPE_TEXT, EText))
-#define E_TEXT_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), E_TYPE_TEXT, ETextClass))
-#define E_IS_TEXT(obj)         (GTK_CHECK_TYPE ((obj), E_TYPE_TEXT))
-#define E_IS_TEXT_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), E_TYPE_TEXT))
+#define E_TEXT(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), E_TYPE_TEXT, EText))
+#define E_TEXT_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), E_TYPE_TEXT, ETextClass))
+#define E_IS_TEXT(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), E_TYPE_TEXT))
+#define E_IS_TEXT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), E_TYPE_TEXT))
 
 
 typedef struct _EText EText;
 typedef struct _ETextClass ETextClass;
 
-#if 0
-typedef struct _ETextSuckFont ETextSuckFont;
-typedef struct _ETextSuckChar ETextSuckChar;
-
-struct _ETextSuckChar {
-	int     left_sb;
-	int     right_sb;
-	int     width;
-	int     ascent;
-	int     descent;
-	int     bitmap_offset; /* in pixels */
-};
-
-struct _ETextSuckFont {
-	guchar *bitmap;
-	gint    bitmap_width;
-	gint    bitmap_height;
-	gint    ascent;
-	ETextSuckChar chars[256];
-};
-#endif
-
 struct _EText {
 	GnomeCanvasItem item;
 	
 	ETextModel *model;
 	gint model_changed_signal_id;
+	gint model_repos_signal_id;
 
-	char *text;			/* Text to display */
-	gpointer lines;			/* Text split into lines (private field) */
+	const gchar *text;              /* Text to display --- from the ETextModel */
+	PangoLayout *layout;
 	int num_lines;			/* Number of lines of text */
 
-#if 0
-	GdkFont *font;			/* Font for text */
-#else
-	EFont *font;
-#endif
+	gchar *revert;                  /* Text to revert to */
+
 	GtkAnchorType anchor;		/* Anchor side for text */
 	GtkJustification justification;	/* Justification for text */
 
@@ -133,28 +126,18 @@ struct _EText {
 	GdkGC *gc;			/* GC for drawing text */
 
 	int cx, cy;			/* Top-left canvas coordinates for text */
+	int text_cx, text_cy;		/* Top-left canvas coordinates for text */
 	int clip_cx, clip_cy;		/* Top-left canvas coordinates for clip rectangle */
 	int clip_cwidth, clip_cheight;	/* Size of clip rectangle in pixels */
 	int max_width;			/* Maximum width of text lines */
 	int width;                      /* Rendered text width in pixels */
 	int height;			/* Rendered text height in pixels */
 
-	guint clip : 1;			/* Use clip rectangle? */
-	guint fill_clip_rectangle : 1;  /* Fill the clipping rectangle. */
-
-	/* Antialiased specific stuff follows */
-#if 0
-	ETextSuckFont *suckfont; /* Sucked font */
-#endif
 	guint32 rgba;			/* RGBA color for text */
 	double affine[6];               /* The item -> canvas affine */
 
 	char *ellipsis;                 /* The ellipsis characters.  NULL = "...". */
 	double ellipsis_width;          /* The width of the ellipsis. */
-	gboolean use_ellipsis;          /* Whether to use the ellipsis. */
-
-	gboolean editable;              /* Item is editable */
-	gboolean editing;               /* Item is currently being edited */
 
 	int xofs_edit;                  /* Offset because of editing */
 	int yofs_edit;                  /* Offset because of editing */
@@ -178,19 +161,36 @@ struct _EText {
 	ETextEventProcessor *tep;       /* Text Event Processor */
 	gint tep_command_id;
 
-	GtkWidget *invisible;           /* For selection handling */
 	gboolean has_selection;         /* TRUE if we have the selection */
-	gchar *primary_selection;       /* Primary selection text */
-	gint primary_length;            /* Primary selection text length */
-	gchar *clipboard_selection;     /* Clipboard selection text */
-	gint clipboard_length;          /* Clipboard selection text length*/
+
+	guint clip : 1;			/* Use clip rectangle? */
+	guint fill_clip_rectangle : 1;  /* Fill the clipping rectangle. */
 
 	guint pointer_in : 1;           /* Is the pointer currently over us? */
 	guint default_cursor_shown : 1; /* Is the default cursor currently shown? */
 	guint draw_borders : 1;         /* Draw borders? */
 	guint draw_background : 1;      /* Draw background? */
+	guint draw_button : 1;          /* Draw button? */
 
 	guint line_wrap : 1;            /* Do line wrap */
+
+	guint needs_redraw : 1;         /* Needs redraw */
+	guint needs_recalc_bounds : 1;  /* Need recalc_bounds */
+	guint needs_calc_height : 1;    /* Need calc_height */
+	guint needs_split_into_lines : 1; /* Needs split_into_lines */
+	guint needs_reset_layout : 1; /* Needs split_into_lines */
+
+	guint bold : 1;
+	guint strikeout : 1;
+
+	guint tooltip_owner : 1;
+	guint allow_newlines : 1;
+
+	guint use_ellipsis : 1;         /* Whether to use the ellipsis. */
+
+	guint editable : 1;             /* Item is editable */
+	guint editing : 1;              /* Item is currently being edited */
+
 	gchar *break_characters;        /* Characters to optionally break after */
 
 	gint max_lines;                 /* Max number of lines (-1 = infinite) */
@@ -199,31 +199,46 @@ struct _EText {
 	GdkCursor *i_cursor;            /* I beam cursor */
 
 	gint tooltip_timeout;           /* Timeout for the tooltip */
-	GtkWidget *tooltip_window;      /* GtkWindow for displaying the tooltip */
 	gint tooltip_count;             /* GDK_ENTER_NOTIFY count. */
 
-	guint needs_redraw : 1;         /* Needs redraw */
-	guint needs_recalc_bounds : 1;  /* Need recalc_bounds */
-	guint needs_calc_height : 1;    /* Need calc_height */
-	guint needs_calc_line_widths : 1; /* Needs calc_line_widths */
-	guint needs_split_into_lines : 1; /* Needs split_into_lines */
-
 	gint dbl_timeout;               /* Double click timeout */
 	gint tpl_timeout;               /* Triple click timeout */
+
+	gint     last_type_request;       /* Last selection type requested. */
+	guint32  last_time_request;       /* The time of the last selection request. */
+	GdkAtom  last_selection_request;  /* The time of the last selection request. */
+	GList   *queued_requests;         /* Queued selection requests. */
+
+	GtkIMContext *im_context;
+	gboolean      need_im_reset;
+	gboolean      im_context_signals_registered;
+
+	gboolean      handle_popup;
+	gboolean      has_popup;
 };
 
 struct _ETextClass {
 	GnomeCanvasItemClass parent_class;
 
-	void (* changed) (EText *text);
-	void (* activate) (EText *text);
+	void (* changed)         (EText *text);
+	void (* activate)        (EText *text);
+	void (* keypress)        (EText *text, guint keyval, guint state);
+	void (* populate_popup)  (EText *text, GdkEventButton *ev, gint pos, GtkMenu *menu);
+	void (* style_set)       (EText *text, GtkStyle *previous_style);
 };
 
 
 /* Standard Gtk function */
-GtkType e_text_get_type (void);
+GtkType  e_text_get_type        (void);
+void     e_text_cancel_editing  (EText *text);
+void     e_text_stop_editing    (EText *text);
 
+void     e_text_delete_selection (EText *text);
+void     e_text_cut_clipboard    (EText *text);
+void     e_text_copy_clipboard   (EText *text);
+void     e_text_paste_clipboard  (EText *text);
+void     e_text_select_all       (EText *text);
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif
