@@ -1,25 +1,24 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-
 /* 
- * Author : 
- *  Damon Chaplin <damon@helixcode.com>
+ * test-shortcut-bar.c
+ * Copyright 2000, 2001, Ximian, Inc.
  *
- * Copyright 1999, Helix Code, Inc.
+ * Authors:
+ *   Damon Chaplin <damon@ximian.com>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License, version 2, as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
  */
 
 /*
@@ -29,7 +28,7 @@
 #include <gnome.h>
 
 #include <gal/shortcut-bar/e-shortcut-bar.h>
-#include <gal/e-paned/e-hpaned.h>
+#include <gtk/gtkhpaned.h>
 
 #define NUM_SHORTCUT_TYPES 5
 gchar *shortcut_types[NUM_SHORTCUT_TYPES] = {
@@ -110,7 +109,6 @@ main (int argc, char *argv[])
 
 	gnome_init ("test-shortcut-bar", "0.1", argc, argv);
 
-	gtk_widget_push_visual (gdk_rgb_get_visual ());
 	gtk_widget_push_colormap (gdk_rgb_get_cmap ());
 
 	window = gnome_app_new ("TestShortcutBar", "TestShortCutBar");
@@ -120,7 +118,7 @@ main (int argc, char *argv[])
 	gtk_signal_connect (GTK_OBJECT (window), "delete-event",
 			    GTK_SIGNAL_FUNC (quit), NULL);
 
-	hpaned = e_hpaned_new ();
+	hpaned = gtk_hpaned_new ();
 	gnome_app_set_contents (GNOME_APP (window), hpaned);
 	gtk_widget_show (hpaned);
 
@@ -129,7 +127,7 @@ main (int argc, char *argv[])
 	shortcut_bar = e_shortcut_bar_new ();
 	e_shortcut_bar_set_model (E_SHORTCUT_BAR (shortcut_bar),
 				  shortcut_model);
-	e_paned_pack1 (E_PANED (hpaned), shortcut_bar, FALSE, TRUE);
+	gtk_paned_pack1 (GTK_PANED (hpaned), shortcut_bar, FALSE, TRUE);
 	gtk_widget_show (shortcut_bar);
 
 #if 0
@@ -155,11 +153,10 @@ main (int argc, char *argv[])
 	gtk_container_set_border_width (GTK_CONTAINER (shortcut_bar), 4);
 #endif
 
-	e_paned_set_position (E_PANED (hpaned), 100);
-	/*e_paned_set_gutter_size (E_PANED (hpaned), 12);*/
+	gtk_paned_set_position (GTK_PANED (hpaned), 100);
 
 	vbox = gtk_vbox_new (FALSE, 0);
-	e_paned_pack2 (E_PANED (hpaned), vbox, TRUE, TRUE);
+	gtk_paned_pack2 (GTK_PANED (hpaned), vbox, TRUE, TRUE);
 	gtk_widget_show (vbox);
 
 
@@ -185,17 +182,17 @@ main (int argc, char *argv[])
 			    shortcut_bar);
 
 
-	gtk_widget_pop_visual ();
 	gtk_widget_pop_colormap ();
 
 	/* Load our default icons. */
 	for (i = 0; i < NUM_SHORTCUT_TYPES; i++) {
 		pathname = gnome_pixmap_file (icon_filenames[i]);
 		if (pathname) {
-			icon_pixbufs[i] = gdk_pixbuf_new_from_file (pathname);
+			icon_pixbufs[i] = gdk_pixbuf_new_from_file (pathname, NULL);
 			g_print ("type %d -- %s %s\n",
 				 i, pathname, icon_pixbufs[i] == NULL ? "(not found)" : "");
 		} else {
+			g_warning ("Failed to locate '%s'", icon_filenames [i]);
 			icon_pixbufs[i] = NULL;
 		}
 	}
@@ -450,11 +447,12 @@ show_context_popup (EShortcutBar *shortcut_bar,
 		    gint group_num,
 		    gint item_num)
 {
-	GtkWidget *menu, *menuitem, *label, *pixmap;
+	GtkWidget *menu, *menuitem, *label;
 
 	menu = gtk_menu_new ();
 
-	menuitem = gtk_pixmap_menu_item_new ();
+	menuitem = gtk_image_menu_item_new_from_stock (
+		GNOME_STOCK_MENU_OPEN, NULL);
 	label = gtk_label_new ("Open Folder");
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_widget_show (label);
@@ -462,11 +460,6 @@ show_context_popup (EShortcutBar *shortcut_bar,
 	gtk_widget_set_sensitive (menuitem, FALSE);
 	gtk_widget_show (menuitem);
 	gtk_menu_append (GTK_MENU (menu), menuitem);
-	pixmap = gnome_stock_pixmap_widget (menu, GNOME_STOCK_MENU_OPEN);
-	if (pixmap) {
-		gtk_widget_show(pixmap);
-		gtk_pixmap_menu_item_set_pixmap (GTK_PIXMAP_MENU_ITEM (menuitem), pixmap);
-	}
 
 	menuitem = gtk_menu_item_new_with_label ("Open in New Window");
 	gtk_widget_set_sensitive (menuitem, FALSE);
